python-jiractl
==============

.. image:: https://travis-ci.org/bgaifullin/python-jiractl.png?branch=master
    :target: https://travis-ci.org/bgaifullin/python-jiractl
.. image:: https://img.shields.io/pypi/v/jiractl.svg
    :target: https://pypi.python.org/pypi/jiractl


The command line interface for Jira REST API

******
Usage
******

************
Requirements
************
- jira>=1.0.10
- pbr>=1.6
- cliff>=1.18.0

*******
Install
*******

Automated
---------
1. **jiractl** can be installed through `easy_install` or `pip`.

.. code-block:: bash

    pip install jiractl


Manual
------

1. Clone the **xmlsec** repository to your local computer.

.. code-block:: bash

    git clone git://github.com/bgaifullin/python-jiractl.git

2. Change into the **jiractl** root directory.

.. code-block:: bash

    cd /path/to/jiractrl


3. Install the project and all its dependencies using `pip`.

.. code-block:: bash

    pip install .


*******
License
*******

Unless otherwise noted, all files contained within this project are liensed under the MIT opensource license.
See the included file LICENSE or visit `opensource.org <http://opensource.org/licenses/MIT>`_ for more information.